==> mls-0.1.tar.gz: mls-0.1/src/panel_remove.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Byoungyoung, La                                 *
 *   la9527@yahoo.co.kr                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 
 
#include <sstream>
#include "panel.h"
#include "dialog.h"
#include "strutil.h"

using namespace std;
using namespace MLS;
using namespace strutil;

int Panel::cmd_zip_remove(void)
{
	int yn=YNBox("Do you want to remove files ?", YN_N);
	
	if (yn == YN_Y)
	{
		WINDOW*	pWin = MsgWaitBox("Wait", "Please wait !!!");
		
		int size = 0;	
		vector<string> &unzip_files=GetSelection(size, false);
		
		if (m_tReader->Remove(unzip_files) == ERROR)
		{
			if (pWin) MsgWaitEnd(pWin);
			MsgBox("ERROR", "Remove Failure !!!");
			return ERROR;
		}
		
		if (pWin) MsgWaitEnd(pWin);
		MsgBox("Message", "Remove Success !!!");
	}
	return SUCCESS;
}

int Panel::cmd_remove(void)
{// 현재디렉토리에서 파일을 지워버립니다... 주의 지금 현재디렉토리에 대한 명시적인 해석이 없음	
	// 지우기 전에 확인. 하는 과정..	
	if (YNBox("Delete?", YN_N, COLOR_RED) == YN_N)	return 0;	
	
	StatBox s("Delete", "");		
	
	s.setUL("Counting files...");
	s.show();
	
	int size = 0, count_file = 0;
	ostringstream BL;
	vector<string> &files = GetSelection(size, true);	// 디렉토리까지..	
	vector<string>::iterator i, end = files.end();	
	vector<string> dir_stack;
	
	string p = toregular(size);	
		
	s.setBR(p.c_str());	
	string tar_dir; // 현재 타겟 디렉토리
	
	for (i = files.begin(); i != end; ++i)
		LOG("%s", (*i).c_str());
	
	for (i = files.begin(); i != end; ++i)
	{
		string &rf = *i;
		
		if (rf.empty()) continue;
		
		// 상대가 디렉토리 라면..		
		if (*rf.rbegin() == '/')  
		{
			while(!dir_stack.empty())
			{
				if (!rf.compare (0, dir_stack.back().size(), dir_stack.back()))
					break;
				
				BL.str("");
				BL << '<' << count_file << '/' << files.size() << '>' ;
				
				s.setU(0);				
				s.setUL(dir_stack.back().c_str());
				s.setBL(BL.str().c_str());								
				s.show();
				
				if (remove(dir_stack.back().c_str()))
				{
					MsgBox(COLOR_RED, "ERROR", "Remove Failure !!! %s", (dir_stack.back().c_str()));
					return 1;					
				}
				count_file++;
				
				s.setU(60);
				s.setB(count_file*60/files.size());
				s.show();
				
				dir_stack.pop_back();					
			}
			dir_stack.push_back(rf);
			tar_dir = rf;
		}		
		else
		{ // 파일을 지운다.
			BL.str("");
			BL << '<' << count_file << '/' << files.size() << '>' ;
			
			s.setU(0);				
			s.setUL((tar_dir + rf).c_str());
			s.setBL(BL.str().c_str());								
			s.show();
			
			if (remove((tar_dir + rf).c_str()))
			{	
				MsgBox(COLOR_RED, "ERROR", "Remove Failure !!! %s", (tar_dir + rf).c_str());
				break;
			}
			count_file++;
			
			s.setU(60);
			s.setB(count_file*60/files.size());
			s.show();
			
			
		}	
	}
	
	// 남은 디렉토리 정리	
	while(!dir_stack.empty())
	{		
		BL.str("");
		BL << '<' << count_file << '/' << files.size() << '>' ;		
		s.setU(0);				
		s.setUL(dir_stack.back().c_str());
		s.setBL(BL.str().c_str());								
		s.show();
		
		if (remove(dir_stack.back().c_str()))
		{
			MsgBox(COLOR_RED, "ERROR", "Remove Failure !!! %s", dir_stack.back().c_str());
			return 1;					
		}
		count_file++;
		
		s.setU(60);
		s.setB(count_file*60/files.size());
		s.show();
		
		dir_stack.pop_back();
	}
	
	Refresh();
	
	return 0;
}

==> mls-0.2.tar.gz: mls-0.2/src/panel_remove.cpp <==
/* *************************************************************************
 *   Copyright (C) 2004 by Byoungyoung, La                                 *
 *   la9527@yahoo.co.kr                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ************************************************************************* */
 
///	\file	panel_remove.cpp
///	\brief	panel_remove.cpp

//#include <sstream>
#include "panel.h"
#include "dialog.h"
#include "strutil.h"

using namespace std;
using namespace MLS;
using namespace strutil;

int Panel::cmd_zip_remove(void)
{
	int yn=YNBox("Do you want to remove files ?", YN_N);
	
	if (yn == YN_Y)
	{
		WINDOW*	pWin = MsgWaitBox("Wait", "Please wait !!!");
		
		int size = 0;	
		vector<string> &unzip_files=GetSelection(size, false);
		
		if (m_tReader->Remove(unzip_files) == ERROR)
		{
			if (pWin) MsgWaitEnd(pWin);
			MsgBox("ERROR", "Remove Failure !!!");
			return ERROR;
		}
		
		if (pWin) MsgWaitEnd(pWin);
		MsgBox("Message", "Remove Success !!!");
	}
	return SUCCESS;
}

int Panel::cmd_remove(void)
{// 현재디렉토리에서 파일을 지워버립니다... 주의 지금 현재디렉토리에 대한 명시적인 해석이 없음	
	// 지우기 전에 확인. 하는 과정..	
	if (YNBox("Delete?", YN_N, COLOR_RED) == YN_N)	return 0;	
	
	StatBox s("Delete", "");		
	
	s.setUL("Counting files...");
	s.show();
	
	int size = 0, count_file = 0;
	//ostringstream BL;
	char	BL[1024];
	vector<string> &files = GetSelection(size, true);	// 디렉토리까지..	
	vector<string>::iterator i, end = files.end();	
	vector<string> dir_stack;
	
	string p = toregular(size);	
		
	s.setBR(p.c_str());	
	string tar_dir; // 현재 타겟 디렉토리
	
	for (i = files.begin(); i != end; ++i)
		LOG("%s", (*i).c_str());
	
	for (i = files.begin(); i != end; ++i)
	{
		string &rf = *i;
		
		if (rf.empty()) continue;
		
		// 상대가 디렉토리 라면..		
		if (*rf.rbegin() == '/')  
		{
			while(!dir_stack.empty())
			{
				//if (!rf.compare (0, dir_stack.back().size(), dir_stack.back()))
				if (rf.substr(0, dir_stack.back().size()) == dir_stack.back())
						break;				
				
				//BL.str("");
				//BL << '<' << count_file << '/' << files.size() << '>' ;
				sprintf(BL, "<%ld/%ld>", count_file, files.size());
				
				s.setU(0);				
				s.setUL(dir_stack.back().c_str());
				s.setBL(BL);	
				s.show();
				
				if (remove(dir_stack.back().c_str()))
				{
					MsgBox(COLOR_RED, "ERROR", "Remove Failure !!! %s", (dir_stack.back().c_str()));
					return 1;					
				}
				count_file++;
				
				s.setU(60);
				s.setB(count_file*60/files.size());
				s.show();
				
				dir_stack.pop_back();					
			}
			dir_stack.push_back(rf);
			tar_dir = rf;
		}		
		else
		{ // 파일을 지운다.
			//BL.str("");
			//BL << '<' << count_file << '/' << files.size() << '>' ;
			sprintf(BL, "<%ld/%ld>", count_file, files.size());
			
			s.setU(0);				
			s.setUL((tar_dir + rf).c_str());
			//s.setBL(BL.str().c_str());								
			s.setBL(BL);
			s.show();
			
			if (remove((tar_dir + rf).c_str()))
			{	
				MsgBox(COLOR_RED, "ERROR", "Remove Failure !!! %s", (tar_dir + rf).c_str());
				break;
			}
			count_file++;
			
			s.setU(60);
			s.setB(count_file*60/files.size());
			s.show();
			
			
		}	
	}
	
	// 남은 디렉토리 정리	
	while(!dir_stack.empty())
	{		
		//BL.str("");
		//BL << '<' << count_file << '/' << files.size() << '>' ;		
		sprintf(BL, "<%ld/%ld>", count_file, files.size());
		
		s.setU(0);				
		s.setUL(dir_stack.back().c_str());
		//s.setBL(BL.str().c_str());								
		s.setBL(BL);
		s.show();
		
		if (remove(dir_stack.back().c_str()))
		{
			MsgBox(COLOR_RED, "ERROR", "Remove Failure !!! %s", dir_stack.back().c_str());
			return 1;					
		}
		count_file++;
		
		s.setU(60);
		s.setB(count_file*60/files.size());
		s.show();
		
		dir_stack.pop_back();
	}
	
	Refresh();
	
	return 0;
}
